@@ -3,8 +3,8 @@
 ;; Copyright (C) 2011-2024 EditorConfig Team
 
 ;; Author: EditorConfig Team <editorconfig@googlegroups.com>
-;; Package-Version: 20251221.650
-;; Package-Revision: 6783cb2a9fb8
+;; Package-Version: 20260118.718
+;; Package-Revision: 1e9931d5f38a
 ;; URL: https://github.com/editorconfig/editorconfig-emacs#readme
 ;; Package-Requires: ((emacs "27.2"))
 ;; Keywords: convenience editorconfig
@@ -838,17 +838,21 @@ F is that function, and FILENAME and ARGS are arguments passed to F."
 (defun editorconfig--get-coding-system (&optional _size)
   "Return the coding system to use according to EditorConfig.
 Meant to be used on `auto-coding-functions'."
-  (when (and (stringp auto-coding-file-name)
-             (file-name-absolute-p auto-coding-file-name)
-	     ;; Don't recurse infinitely.
-	     (not (member auto-coding-file-name
-	                  editorconfig--getting-coding-system)))
-    (let* ((editorconfig--getting-coding-system
-            (cons auto-coding-file-name editorconfig--getting-coding-system))
-           (props (editorconfig-call-get-properties-function
-                   auto-coding-file-name)))
-      (editorconfig-merge-coding-systems (gethash 'end_of_line props)
-                                         (gethash 'charset props)))))
+  ;; Not only we don't want that an error in the `.editorconfig' file
+  ;; prevents opening a file but we don't want an error to be dropped on
+  ;; the floor by some `ignore-errors' higher up.
+  (with-demoted-errors "EditorConfig: %S"
+    (when (and (stringp auto-coding-file-name)
+               (file-name-absolute-p auto-coding-file-name)
+	       ;; Don't recurse infinitely.
+	       (not (member auto-coding-file-name
+	                    editorconfig--getting-coding-system)))
+      (let* ((editorconfig--getting-coding-system
+              (cons auto-coding-file-name editorconfig--getting-coding-system))
+             (props (editorconfig-call-get-properties-function
+                     auto-coding-file-name)))
+        (editorconfig-merge-coding-systems (gethash 'end_of_line props)
+                                           (gethash 'charset props))))))
 
 ;;;###autoload
 (define-minor-mode editorconfig-mode
